@@ -17,14 +17,13 @@ class ContactFormMixin(object):
     """    
     def form_valid(self, form):
         form.send_email(self.request)
-        return super(ContactFormObject, self).form_valid(form)
+        return super(ContactFormMixin, self).form_valid(form)
 
     def get_success_url(self):		
         return reverse("feedback_form:completed")
 
 	def get_context_data(self, **kwargs):
 		context = super(ContactFormObject, self).get_context_data(**kwargs)
-		context['messagez'] = "1111"
 		return context
 	
 class ContactFormView(ContactFormMixin, FormView):
